cocos2d 0.6.10 Documentation Index — cocos v0.6.10 documentation

# cocos2d 0.6.10 Documentation Index

cocos2d is a framework for building 2D games, demos, and other graphical/interactive applications.

It works on Windows, OS X and Linux and it is meant to be used by applications written in the python language.

## Programming Guide

- cocos2d Programming Guide
  - Introduction
  - Installation, Dependencies and Compatibility
  - Writing a cocos2d application
  - Basic Concepts
  - Actions, Transformations and Effects
  - Scenes & Transitions
  - Tiled maps
  - Map Colliders
  - CocosNodes
  - Built-in Python Interpreter
  - Default Handlers
  - Collision
  - Skeletal Animations
  - A few tips on threading and multiprocessing

## API Reference

Note

- Type annotations in the API reference uses python 3 types

- When text strings are expected (`str` in py3) `str` or `unicode` are accepted in py2.

- To future proof your code please use `unicode` for text strings.

- cocos package
  - Subpackages
    - cocos.actions package
    - cocos.audio package
    - cocos.layer package
    - cocos.scenes package
  - Submodules
    - cocos.batch module
    - cocos.camera module
    - cocos.cocosnode module
    - cocos.collision_model module
    - cocos.compat module
    - cocos.custom_clocks module
    - cocos.director module
    - cocos.draw module
    - cocos.euclid module
    - cocos.fps module
    - cocos.framegrabber module
    - cocos.gl_framebuffer_object module
    - cocos.grid module
    - cocos.mapcolliders module
    - cocos.menu module
    - cocos.particle module
    - cocos.particle_systems module
    - cocos.path module
    - cocos.rect module
    - cocos.scene module
    - cocos.shader module
    - cocos.skeleton module
    - cocos.sprite module
    - cocos.text module
    - cocos.tiles module
    - cocos.utils module
    - cocos.wired module
  - Module contents
    - Main Features

bundled euclid docs

## Compatibility Notes

- cocos 0.6.10
- cocos 0.6.9
- cocos 0.6.8
- cocos 0.6.7
- cocos 0.6.6
- cocos 0.6.5
- cocos 0.6.4

## Frequently Asked Questions

- FAQ
  - cocos2d Frequently Asked Questions

## Dev notes

- dev
  - Documentation Notes
  - Testing and Building Release
  - Contributing
  - Reference dependencies used on last cocos2d build

## Related documentation

> - pyglet Programming Guide

> - pyglet API Reference

> - OpenGL Programming Guide

> - OpenGL Reference Pages

## Indices and tables

- Index

- Module Index

- Search Page